CVS commit: src/sys/dev/pci/ixgbe

2023-12-07 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Fri Dec  8 05:42:59 UTC 2023

Modified Files:
src/sys/dev/pci/ixgbe: ix_txrx.c

Log Message:
ixgbe: Update if_opackets outside the loop in ixgbe_txeof().


To generate a diff of this commit:
cvs rdiff -u -r1.109 -r1.110 src/sys/dev/pci/ixgbe/ix_txrx.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/ixgbe/ix_txrx.c
diff -u src/sys/dev/pci/ixgbe/ix_txrx.c:1.109 src/sys/dev/pci/ixgbe/ix_txrx.c:1.110
--- src/sys/dev/pci/ixgbe/ix_txrx.c:1.109	Fri Dec  8 05:39:27 2023
+++ src/sys/dev/pci/ixgbe/ix_txrx.c	Fri Dec  8 05:42:59 2023
@@ -1,4 +1,4 @@
-/* $NetBSD: ix_txrx.c,v 1.109 2023/12/08 05:39:27 msaitoh Exp $ */
+/* $NetBSD: ix_txrx.c,v 1.110 2023/12/08 05:42:59 msaitoh Exp $ */
 
 /**
 
@@ -64,7 +64,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: ix_txrx.c,v 1.109 2023/12/08 05:39:27 msaitoh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ix_txrx.c,v 1.110 2023/12/08 05:42:59 msaitoh Exp $");
 
 #include "opt_inet.h"
 #include "opt_inet6.h"
@@ -1205,7 +1205,6 @@ ixgbe_txeof(struct tx_ring *txr)
 		}
 		++txr->packets;
 		++processed;
-		if_statinc(ifp, if_opackets);
 
 		/* Try the next packet */
 		++txd;
@@ -1228,6 +1227,7 @@ ixgbe_txeof(struct tx_ring *txr)
 	if (processed) {
 		txr->tx_avail = avail;
 		txr->txr_no_space = false;
+		if_statadd(ifp, if_opackets, processed);
 	}
 
 	/*



CVS commit: src/sys/dev/pci/ixgbe

2023-12-07 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Fri Dec  8 05:42:59 UTC 2023

Modified Files:
src/sys/dev/pci/ixgbe: ix_txrx.c

Log Message:
ixgbe: Update if_opackets outside the loop in ixgbe_txeof().


To generate a diff of this commit:
cvs rdiff -u -r1.109 -r1.110 src/sys/dev/pci/ixgbe/ix_txrx.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/dev/pci/ixgbe

2023-12-07 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Fri Dec  8 05:39:27 UTC 2023

Modified Files:
src/sys/dev/pci/ixgbe: ix_txrx.c

Log Message:
ixgbe: micro-optimize ixgbe_txeof()

 Update txr->tx_avail and txr->txr_no_space outside the loop in ixgbe_txeof().


To generate a diff of this commit:
cvs rdiff -u -r1.108 -r1.109 src/sys/dev/pci/ixgbe/ix_txrx.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/dev/pci/ixgbe

2023-12-07 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Fri Dec  8 05:39:27 UTC 2023

Modified Files:
src/sys/dev/pci/ixgbe: ix_txrx.c

Log Message:
ixgbe: micro-optimize ixgbe_txeof()

 Update txr->tx_avail and txr->txr_no_space outside the loop in ixgbe_txeof().


To generate a diff of this commit:
cvs rdiff -u -r1.108 -r1.109 src/sys/dev/pci/ixgbe/ix_txrx.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/ixgbe/ix_txrx.c
diff -u src/sys/dev/pci/ixgbe/ix_txrx.c:1.108 src/sys/dev/pci/ixgbe/ix_txrx.c:1.109
--- src/sys/dev/pci/ixgbe/ix_txrx.c:1.108	Thu Nov 16 05:39:08 2023
+++ src/sys/dev/pci/ixgbe/ix_txrx.c	Fri Dec  8 05:39:27 2023
@@ -1,4 +1,4 @@
-/* $NetBSD: ix_txrx.c,v 1.108 2023/11/16 05:39:08 msaitoh Exp $ */
+/* $NetBSD: ix_txrx.c,v 1.109 2023/12/08 05:39:27 msaitoh Exp $ */
 
 /**
 
@@ -64,7 +64,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: ix_txrx.c,v 1.108 2023/11/16 05:39:08 msaitoh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ix_txrx.c,v 1.109 2023/12/08 05:39:27 msaitoh Exp $");
 
 #include "opt_inet.h"
 #include "opt_inet6.h"
@@ -1108,6 +1108,7 @@ ixgbe_txeof(struct tx_ring *txr)
 	union ixgbe_adv_tx_desc *txd;
 	u32			work, processed = 0;
 	u32			limit = sc->tx_process_limit;
+	u16			avail;
 
 	KASSERT(mutex_owned(>tx_mtx));
 
@@ -1151,6 +1152,7 @@ ixgbe_txeof(struct tx_ring *txr)
 	buf = >tx_buffers[work];
 	txd = >tx_base[work];
 	work -= txr->num_desc; /* The distance to ring end */
+	avail = txr->tx_avail;
 	ixgbe_dmamap_sync(txr->txdma.dma_tag, txr->txdma.dma_map,
 	BUS_DMASYNC_POSTREAD);
 
@@ -1172,8 +1174,7 @@ ixgbe_txeof(struct tx_ring *txr)
 			buf->m_head = NULL;
 		}
 		buf->eop = NULL;
-		txr->txr_no_space = false;
-		++txr->tx_avail;
+		++avail;
 
 		/* We clean the range if multi segment */
 		while (txd != eop) {
@@ -1198,7 +1199,7 @@ ixgbe_txeof(struct tx_ring *txr)
 m_freem(buf->m_head);
 buf->m_head = NULL;
 			}
-			++txr->tx_avail;
+			++avail;
 			buf->eop = NULL;
 
 		}
@@ -1224,6 +1225,10 @@ ixgbe_txeof(struct tx_ring *txr)
 
 	work += txr->num_desc;
 	txr->next_to_clean = work;
+	if (processed) {
+		txr->tx_avail = avail;
+		txr->txr_no_space = false;
+	}
 
 	/*
 	 * Queue Hang detection, we know there's



CVS commit: src/sys/arch/mipsco

2023-12-07 Thread Jason R Thorpe
Module Name:src
Committed By:   thorpej
Date:   Fri Dec  8 01:38:20 UTC 2023

Modified Files:
src/sys/arch/mipsco/include: bus.h
src/sys/arch/mipsco/mipsco: bus_space.c

Log Message:
Excise extent(9) from the mipsco bus_space -- it was completely unused,
so let's make the code smaller.


To generate a diff of this commit:
cvs rdiff -u -r1.24 -r1.25 src/sys/arch/mipsco/include/bus.h
cvs rdiff -u -r1.12 -r1.13 src/sys/arch/mipsco/mipsco/bus_space.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/mipsco/include/bus.h
diff -u src/sys/arch/mipsco/include/bus.h:1.24 src/sys/arch/mipsco/include/bus.h:1.25
--- src/sys/arch/mipsco/include/bus.h:1.24	Sun Oct  8 22:10:49 2023
+++ src/sys/arch/mipsco/include/bus.h	Fri Dec  8 01:38:20 2023
@@ -1,4 +1,4 @@
-/*	$NetBSD: bus.h,v 1.24 2023/10/08 22:10:49 andvar Exp $	*/
+/*	$NetBSD: bus.h,v 1.25 2023/12/08 01:38:20 thorpej Exp $	*/
 
 /*-
  * Copyright (c) 1996, 1997, 1998, 2001 The NetBSD Foundation, Inc.
@@ -115,7 +115,7 @@ typedef struct mipsco_bus_space *bus_spa
 
 struct mipsco_bus_space {
 	const char	*bs_name;
-	struct extent	*bs_extent;
+	void		*bs_spare;	/* (was previously unused extent map) */
 	bus_addr_t	bs_start;
 	bus_size_t	bs_size;
 
@@ -175,19 +175,14 @@ struct mipsco_bus_space {
 #define MIPSCO_BUS_SPACE_UNMAPPED	((vaddr_t)0)
 
 /* machine dependent utility function for bus_space users */
-void	mipsco_bus_space_malloc_set_safe(void);
 void	mipsco_bus_space_init(bus_space_tag_t, const char *,
 	paddr_t, vaddr_t, bus_addr_t, bus_size_t);
-void	mipsco_bus_space_init_extent(bus_space_tag_t, void *, size_t);
 void	mipsco_bus_space_set_aligned_stride(bus_space_tag_t, unsigned int);
 void	mipsco_sparse_bus_space_init(bus_space_tag_t, const char *,
 	paddr_t, bus_addr_t, bus_size_t);
 void	mipsco_large_bus_space_init(bus_space_tag_t, const char *,
 	paddr_t, bus_addr_t, bus_size_t);
 
-/* machine dependent utility function for bus_space implementations */
-int	mipsco_bus_space_extent_malloc_flag(void);
-
 /* these are provided for subclasses which override base bus_space. */
 
 int	mipsco_bus_space_compose_handle(bus_space_tag_t,

Index: src/sys/arch/mipsco/mipsco/bus_space.c
diff -u src/sys/arch/mipsco/mipsco/bus_space.c:1.12 src/sys/arch/mipsco/mipsco/bus_space.c:1.13
--- src/sys/arch/mipsco/mipsco/bus_space.c:1.12	Fri Jan 27 18:52:59 2012
+++ src/sys/arch/mipsco/mipsco/bus_space.c	Fri Dec  8 01:38:20 2023
@@ -1,4 +1,4 @@
-/*	$NetBSD: bus_space.c,v 1.12 2012/01/27 18:52:59 para Exp $ 	*/
+/*	$NetBSD: bus_space.c,v 1.13 2023/12/08 01:38:20 thorpej Exp $ 	*/
 
 /*
  * Copyright (c) 1996, 1997, 1998 The NetBSD Foundation, Inc.
@@ -31,12 +31,11 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: bus_space.c,v 1.12 2012/01/27 18:52:59 para Exp $");
+__KERNEL_RCSID(0, "$NetBSD: bus_space.c,v 1.13 2023/12/08 01:38:20 thorpej Exp $");
 
 #include 
 #include 
 #include 
-#include 
 
 #include 
 
@@ -46,7 +45,7 @@ void
 mipsco_bus_space_init(bus_space_tag_t bst, const char *name, paddr_t paddr, vaddr_t vaddr, bus_addr_t start, bus_size_t size)
 {
 	bst->bs_name = name;
-	bst->bs_extent = NULL;
+	bst->bs_spare = NULL;
 	bst->bs_start = start;
 	bst->bs_size = size;
 	bst->bs_pbase = paddr;
@@ -66,17 +65,6 @@ mipsco_bus_space_init(bus_space_tag_t bs
 }
 
 void
-mipsco_bus_space_init_extent(bus_space_tag_t bst, void *storage, size_t storagesize)
-{
-	bst->bs_extent = extent_create(bst->bs_name,
-	bst->bs_start, bst->bs_start + bst->bs_size,
-	storage, storagesize, EX_NOWAIT);
-	if (bst->bs_extent == NULL)
-	panic("mipsco_bus_space_init_extent: cannot create extent map %s",
-		  bst->bs_name);
-}
-
-void
 mipsco_bus_space_set_aligned_stride(bus_space_tag_t bst, unsigned int shift)
 	/* shift:		 log2(alignment) */
 {
@@ -93,20 +81,6 @@ mipsco_bus_space_set_aligned_stride(bus_
 	bst->bs_offset_8 = 0;
 }
 
-static int malloc_safe = 0;
-
-void
-mipsco_bus_space_malloc_set_safe(void)
-{
-	malloc_safe = EX_MALLOCOK;
-}
-
-int
-mipsco_bus_space_extent_malloc_flag(void)
-{
-	return (malloc_safe);
-}
-
 int
 mipsco_bus_space_compose_handle(bus_space_tag_t bst, bus_addr_t addr, bus_size_t size, int flags, bus_space_handle_t *bshp)
 {
@@ -171,38 +145,16 @@ mipsco_bus_space_paddr(bus_space_tag_t b
 int
 mipsco_bus_space_map(bus_space_tag_t bst, bus_addr_t addr, bus_size_t size, int flags, bus_space_handle_t *bshp)
 {
-	int err;
 
 	if (addr < bst->bs_start || addr + size > bst->bs_start + bst->bs_size)
 		return (EINVAL);
 
-	if (bst->bs_extent != NULL) {
-		err = extent_alloc_region(bst->bs_extent, addr, size,
-		EX_NOWAIT | malloc_safe);
-		if (err)
-			return (err);
-	}
-
 	return (bus_space_compose_handle(bst, addr, size, flags, bshp));
 }
 
 void
 mipsco_bus_space_unmap(bus_space_tag_t bst, bus_space_handle_t bsh, bus_size_t size)
 {
-	if (bst->bs_extent != NULL) {
-		paddr_t pa;
-		bus_addr_t addr;
-		int err;
-
-		/* 

CVS commit: src/sys/arch/mipsco

2023-12-07 Thread Jason R Thorpe
Module Name:src
Committed By:   thorpej
Date:   Fri Dec  8 01:38:20 UTC 2023

Modified Files:
src/sys/arch/mipsco/include: bus.h
src/sys/arch/mipsco/mipsco: bus_space.c

Log Message:
Excise extent(9) from the mipsco bus_space -- it was completely unused,
so let's make the code smaller.


To generate a diff of this commit:
cvs rdiff -u -r1.24 -r1.25 src/sys/arch/mipsco/include/bus.h
cvs rdiff -u -r1.12 -r1.13 src/sys/arch/mipsco/mipsco/bus_space.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



Re: CVS commit: src/lib/libc/time

2023-12-07 Thread Steffen Nurpmeso
Valery Ushakov wrote in
 :
 |On Fri, Dec 08, 2023 at 01:32:49 +0300, Valery Ushakov wrote:
 |
 |> On Thu, Dec 07, 2023 at 20:13:37 +, Robert Elz wrote:
 |>
 |>> While here, consistemntly use minus when minus is meant, rather that
 |>> just using a hyphen.
 |>
 |> One has to be careful with this.
 |
 |And to have this on record for refernce: https://lwn.net/Articles/947941/

'Could be you like that:

  https://lists.gnu.org/archive/html/groff/2022-09/msg00048.html

(or these

  https://lists.gnu.org/archive/html/groff/2022-09/msg00053.html
  https://lists.gnu.org/archive/html/groff/2022-09/msg00057.html

heck i could vomit all thread long. :-)

 |-uwe
 --End of 

Ciao.

--steffen
|
|Der Kragenbaer,The moon bear,
|der holt sich munter   he cheerfully and one by one
|einen nach dem anderen runter  wa.ks himself off
|(By Robert Gernhardt)
|
| Only in December: lightful Dubai COP28 Narendra Modi quote:
|  A small part of humanity has ruthlessly exploited nature.
|  But the entire humanity is bearing the cost of it,
|  especially the inhabitants of the Global South.
|  The selfishness of a few will lead the world into darkness,
|  not just for themselves but for the entire world.


Re: CVS commit: src/lib/libc/time

2023-12-07 Thread Valery Ushakov
On Fri, Dec 08, 2023 at 01:32:49 +0300, Valery Ushakov wrote:

> On Thu, Dec 07, 2023 at 20:13:37 +, Robert Elz wrote:
>
> > While here, consistemntly use minus when minus is meant, rather that
> > just using a hyphen.
>
> One has to be careful with this.

And to have this on record for refernce: https://lwn.net/Articles/947941/

-uwe


CVS commit: src/lib/libc/time

2023-12-07 Thread Robert Elz
Module Name:src
Committed By:   kre
Date:   Thu Dec  7 23:42:28 UTC 2023

Modified Files:
src/lib/libc/time: zic.8

Log Message:
Fix yet another wording (editing) botch noticed by uwe@


To generate a diff of this commit:
cvs rdiff -u -r1.48 -r1.49 src/lib/libc/time/zic.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/time/zic.8
diff -u src/lib/libc/time/zic.8:1.48 src/lib/libc/time/zic.8:1.49
--- src/lib/libc/time/zic.8:1.48	Thu Dec  7 23:21:21 2023
+++ src/lib/libc/time/zic.8	Thu Dec  7 23:42:28 2023
@@ -1,4 +1,4 @@
-.\" $NetBSD: zic.8,v 1.48 2023/12/07 23:21:21 uwe Exp $
+.\" $NetBSD: zic.8,v 1.49 2023/12/07 23:42:28 kre Exp $
 .\" @(#)zic.8	8.6
 .\" This file is in the public domain, so clarified as of
 .\" 2009-05-17 by Arthur David Olson.
@@ -883,7 +883,7 @@ and Swiss daylight saving rules (defined
 .Qq "Rule Swiss"
 apply.
 From 1981 to the present, EU daylight saving rules have
-From 1981 to the present, EU daylight saving rules have
+applied, and the UTC offset has remained at one hour.
 .Pp
 In 1941 and 1942, daylight saving time applied from the first Monday
 in May at 01:00 to the first Monday in October at 02:00.



CVS commit: src/lib/libc/time

2023-12-07 Thread Robert Elz
Module Name:src
Committed By:   kre
Date:   Thu Dec  7 23:42:28 UTC 2023

Modified Files:
src/lib/libc/time: zic.8

Log Message:
Fix yet another wording (editing) botch noticed by uwe@


To generate a diff of this commit:
cvs rdiff -u -r1.48 -r1.49 src/lib/libc/time/zic.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/lib/libc/time

2023-12-07 Thread Valery Ushakov
Module Name:src
Committed By:   uwe
Date:   Thu Dec  7 23:21:21 UTC 2023

Modified Files:
src/lib/libc/time: zic.8

Log Message:
zic(8): missed a .Ql


To generate a diff of this commit:
cvs rdiff -u -r1.47 -r1.48 src/lib/libc/time/zic.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/time/zic.8
diff -u src/lib/libc/time/zic.8:1.47 src/lib/libc/time/zic.8:1.48
--- src/lib/libc/time/zic.8:1.47	Thu Dec  7 20:13:37 2023
+++ src/lib/libc/time/zic.8	Thu Dec  7 23:21:21 2023
@@ -1,4 +1,4 @@
-.\" $NetBSD: zic.8,v 1.47 2023/12/07 20:13:37 kre Exp $
+.\" $NetBSD: zic.8,v 1.48 2023/12/07 23:21:21 uwe Exp $
 .\" @(#)zic.8	8.6
 .\" This file is in the public domain, so clarified as of
 .\" 2009-05-17 by Arthur David Olson.
@@ -126,7 +126,7 @@ are possibly signed decimal counts of se
 (1970-01-01 00:00:00 UTC).
 Omitted counts default to extreme values.
 The output files use UT offset 0 and abbreviation
-.Qq \&\-00
+.Ql \&\-00
 in place of the omitted timestamp data.
 For example,
 .Pp



CVS commit: src/lib/libc/time

2023-12-07 Thread Valery Ushakov
Module Name:src
Committed By:   uwe
Date:   Thu Dec  7 23:21:21 UTC 2023

Modified Files:
src/lib/libc/time: zic.8

Log Message:
zic(8): missed a .Ql


To generate a diff of this commit:
cvs rdiff -u -r1.47 -r1.48 src/lib/libc/time/zic.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/lib/libc/net

2023-12-07 Thread Robert Elz
Module Name:src
Committed By:   kre
Date:   Thu Dec  7 22:33:49 UTC 2023

Modified Files:
src/lib/libc/net: sethostent.c

Log Message:
Fix a couple of (not very likely) memory leaks, reported by e...@google.com
who attributed them:

  the malloc one was reported to Android (as
  https://android-review.googlesource.com/c/platform/bionic/+/2856549)
  by wuhaitao3 ; Chris Ferris
   then spotted the goto nospc one.


To generate a diff of this commit:
cvs rdiff -u -r1.20 -r1.21 src/lib/libc/net/sethostent.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/net/sethostent.c
diff -u src/lib/libc/net/sethostent.c:1.20 src/lib/libc/net/sethostent.c:1.21
--- src/lib/libc/net/sethostent.c:1.20	Mon Mar 17 13:24:23 2014
+++ src/lib/libc/net/sethostent.c	Thu Dec  7 22:33:49 2023
@@ -1,4 +1,4 @@
-/*	$NetBSD: sethostent.c,v 1.20 2014/03/17 13:24:23 christos Exp $	*/
+/*	$NetBSD: sethostent.c,v 1.21 2023/12/07 22:33:49 kre Exp $	*/
 
 /*
  * Copyright (c) 1985, 1993
@@ -35,7 +35,7 @@
 static char sccsid[] = "@(#)sethostent.c	8.1 (Berkeley) 6/4/93";
 static char rcsid[] = "Id: sethostent.c,v 8.5 1996/09/28 06:51:07 vixie Exp ";
 #else
-__RCSID("$NetBSD: sethostent.c,v 1.20 2014/03/17 13:24:23 christos Exp $");
+__RCSID("$NetBSD: sethostent.c,v 1.21 2023/12/07 22:33:49 kre Exp $");
 #endif
 #endif /* LIBC_SCCS and not lint */
 
@@ -171,6 +171,7 @@ _hf_gethtbyname2(const char *name, int a
 	}
 
 	if ((ptr = buf = malloc(len = info->buflen)) == NULL) {
+		endhostent_r();
 		*info->he = NETDB_INTERNAL;
 		return NULL;
 	}
@@ -251,6 +252,7 @@ _hf_gethtbyname2(const char *name, int a
 	free(buf);
 	return hp;
 nospc:
+	endhostent_r();
 	*info->he = NETDB_INTERNAL;
 	free(buf);
 	errno = ENOSPC;



CVS commit: src/lib/libc/net

2023-12-07 Thread Robert Elz
Module Name:src
Committed By:   kre
Date:   Thu Dec  7 22:33:49 UTC 2023

Modified Files:
src/lib/libc/net: sethostent.c

Log Message:
Fix a couple of (not very likely) memory leaks, reported by e...@google.com
who attributed them:

  the malloc one was reported to Android (as
  https://android-review.googlesource.com/c/platform/bionic/+/2856549)
  by wuhaitao3 ; Chris Ferris
   then spotted the goto nospc one.


To generate a diff of this commit:
cvs rdiff -u -r1.20 -r1.21 src/lib/libc/net/sethostent.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



Re: CVS commit: src/lib/libc/time

2023-12-07 Thread Valery Ushakov
On Thu, Dec 07, 2023 at 20:13:37 +, Robert Elz wrote:

> While here, consistemntly use minus when minus is meant, rather that
> just using a hyphen.

One has to be careful with this.  In the literal context (Ql, Li, etc)
the ascii minus-hyphen in the input is preserved as such.  In other
contexts you will get a math minus sign in PS/PDF output, or groff
UTF-8 text output, which makes man page not copy-pastable.  And wide
(about the size of en-dash) minus sign looks rather ugly in non math
contexts like 02:00 CST (−06) in PS/PDF.

-uwe


CVS commit: src/lib/libc/time

2023-12-07 Thread Robert Elz
Module Name:src
Committed By:   kre
Date:   Thu Dec  7 20:13:37 UTC 2023

Modified Files:
src/lib/libc/time: zic.8

Log Message:
Fix a wording botch noticed by uwe@ (and one more smaller one), and
a few more markup issues.   While here, consistemntly use minus when
minus is meant, rather that just using a hyphen.


To generate a diff of this commit:
cvs rdiff -u -r1.46 -r1.47 src/lib/libc/time/zic.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/time/zic.8
diff -u src/lib/libc/time/zic.8:1.46 src/lib/libc/time/zic.8:1.47
--- src/lib/libc/time/zic.8:1.46	Thu Dec  7 16:16:03 2023
+++ src/lib/libc/time/zic.8	Thu Dec  7 20:13:37 2023
@@ -1,4 +1,4 @@
-.\" $NetBSD: zic.8,v 1.46 2023/12/07 16:16:03 uwe Exp $
+.\" $NetBSD: zic.8,v 1.47 2023/12/07 20:13:37 kre Exp $
 .\" @(#)zic.8	8.6
 .\" This file is in the public domain, so clarified as of
 .\" 2009-05-17 by Arthur David Olson.
@@ -11,8 +11,8 @@
 .Nd timezone compiler
 .Sh SYNOPSIS
 .Nm
-.Op Fl \-version
-.Op Fl \-help
+.Op Fl Fl version
+.Op Fl Fl help
 .Op Fl b
 .Op Fl d Ar directory
 .Op Fl L Ar leapsecondfilename
@@ -32,7 +32,7 @@ specified in this input.
 If a
 .Ar file
 is
-.Ql \&- ,
+.Ql \&\- ,
 standard input is read.
 .Ss Options
 .Bl -tag -width Fl
@@ -79,7 +79,7 @@ will act as if the input contained a lin
 If
 .Ar timezone
 is
-.Ql - ,
+.Ql \&\- ,
 any already-existing link is removed.
 .It Fl L Ar leapsecondfilename
 Read leap second information from the file with the given name.
@@ -89,7 +89,7 @@ no leap second information appears in ou
 Use
 .Ar timezone Ap s
 rules when handling POSIX-format TZ strings like
-.Ql EET-2EEST
+.Ql EET\-2EEST
 that lack transition rules.
 .Nm
 will act as if the input contained a link line of the form
@@ -99,7 +99,7 @@ will act as if the input contained a lin
 Unless
 .Ar timezone
 is
-.Ql - ,
+.Ql \&\- ,
 this option is obsolete and poorly supported.
 Among other things it should not be used for timestamps after the year 2037,
 and it should not be combined with
@@ -110,7 +110,7 @@ transitions are at standard time or Univ
 If
 .Ar timezone
 is
-.Ql - ,
+.Ql \&\- ,
 any already-existing link is removed.
 .It Fl r Op Cm @ Ns Ar lo Ns Op Cm /@ Ns Ar hi
 Limit the applicability of output files
@@ -126,7 +126,7 @@ are possibly signed decimal counts of se
 (1970-01-01 00:00:00 UTC).
 Omitted counts default to extreme values.
 The output files use UT offset 0 and abbreviation
-.Qq "\*-00"
+.Qq \&\-00
 in place of the omitted timestamp data.
 For example,
 .Pp
@@ -256,13 +256,13 @@ POSIX requires at least 3, and requires 
 at least 6.
 .It
 An output file name contains a byte that is not an ASCII letter,
-.Ql - ,
+.Ql \&\- ,
 .Ql / ,
 or
 .Ql _ ;
 or it contains a file name component that contains more than 14 bytes
 or that starts with
-.Ql - .
+.Ql \&\- .
 .El
 .El
 .\"
@@ -328,13 +328,13 @@ A
 has the form
 .Pp
 .Bl -column -compact -offset indent "Rule" "NAME" "FROM" "1995" "\&*" "Apr" "lastSun" "2:00w" "1:00d" "LETTER/S"
-.It Rule	NAME	FROM	TO	\&-	IN	ON	AT	SAVE	LETTER/S
+.It Rule	NAME	FROM	TO	\&\-	IN	ON	AT	SAVE	LETTER/S
 .El
 .Pp
 For example:
 .Pp
 .Bl -column -compact -offset indent "Rule" "NAME" "FROM" "1995" "\&*" "Apr" "lastSun" "2:00w" "1:00d" "LETTER/S"
-.It Rule	US	1967	1973	\&-	Apr	lastSun	2:00w	1:00d	D
+.It Rule	US	1967	1973	\&\-	Apr	lastSun	2:00w	1:00d	D
 .El
 .Pp
 The fields that make up a rule line are:
@@ -345,7 +345,7 @@ Gives the name of the rule set that cont
 The name must start with a character that is neither an
 .Tn ASCII
 digit nor
-.Ql -
+.Ql \&\-
 nor
 .Ql + .
 To allow for future extensions,
@@ -380,16 +380,16 @@ may be used to repeat the value of the
 .Ar FROM
 field.
 .\"
-.It Cm \&-
-should be
-.Ql \&-
+.It Cm \&\-
+should always be
+.Ql \&\-
 for compatibility with older versions of
 .Nm .
 It was previously known as the
 .Ar TYPE
 field, which could contain values to allow a
 separate script to further restrict in which
-.Em types
+.Qq types
 of years the rule would apply.
 .\"
 .It Ar IN
@@ -458,9 +458,9 @@ midday, 12 hours after 00:00
 end of day, 24 hours after 00:00
 .It Li 260:00
 260 hours after 00:00
-.It Li -2:30
+.It Li \-2:30
 2.5 hours before 00:00
-.It Li -
+.It Li \-
 equivalent to 0
 .El
 .Pp
@@ -500,8 +500,7 @@ Gives the amount of time to be added to 
 effect, and whether the resulting time is standard or daylight saving.
 This field has the same format as the
 .Ar AT
-field
-.\" XXX: edito?
+field, except with a different set of suffix letters:
 .Ql s
 for standard time and
 .Ql d
@@ -534,7 +533,7 @@ or
 .Ql EDT )
 of time zone abbreviations to be used when this rule is in effect.
 If this field is
-.Ql - ,
+.Ql \&\- ,
 the variable part is null.
 .El
 .\"
@@ -585,7 +584,7 @@ alternatively, a field in the same forma
 column, giving the amount of time to be added to local standard time
 and whether the resulting time is standard or daylight saving.
 If 

CVS commit: src/lib/libc/time

2023-12-07 Thread Robert Elz
Module Name:src
Committed By:   kre
Date:   Thu Dec  7 20:13:37 UTC 2023

Modified Files:
src/lib/libc/time: zic.8

Log Message:
Fix a wording botch noticed by uwe@ (and one more smaller one), and
a few more markup issues.   While here, consistemntly use minus when
minus is meant, rather that just using a hyphen.


To generate a diff of this commit:
cvs rdiff -u -r1.46 -r1.47 src/lib/libc/time/zic.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/bin/cat

2023-12-07 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Thu Dec  7 20:02:07 UTC 2023

Modified Files:
src/bin/cat: cat.c

Log Message:
cat: reduce visibility of local functions

No functional change.


To generate a diff of this commit:
cvs rdiff -u -r1.58 -r1.59 src/bin/cat/cat.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/bin/cat/cat.c
diff -u src/bin/cat/cat.c:1.58 src/bin/cat/cat.c:1.59
--- src/bin/cat/cat.c:1.58	Fri May 19 05:28:54 2023
+++ src/bin/cat/cat.c	Thu Dec  7 20:02:07 2023
@@ -1,4 +1,4 @@
-/* $NetBSD: cat.c,v 1.58 2023/05/19 05:28:54 rillig Exp $	*/
+/* $NetBSD: cat.c,v 1.59 2023/12/07 20:02:07 rillig Exp $	*/
 
 /*
  * Copyright (c) 1989, 1993
@@ -44,7 +44,7 @@ __COPYRIGHT(
 #if 0
 static char sccsid[] = "@(#)cat.c	8.2 (Berkeley) 4/27/95";
 #else
-__RCSID("$NetBSD: cat.c,v 1.58 2023/05/19 05:28:54 rillig Exp $");
+__RCSID("$NetBSD: cat.c,v 1.59 2023/12/07 20:02:07 rillig Exp $");
 #endif
 #endif /* not lint */
 
@@ -66,10 +66,10 @@ static size_t bsize;
 static int rval;
 static const char *filename;
 
-void cook_args(char *argv[]);
-void cook_buf(FILE *);
-void raw_args(char *argv[]);
-void raw_cat(int);
+static void cook_args(char *argv[]);
+static void cook_buf(FILE *);
+static void raw_args(char *argv[]);
+static void raw_cat(int);
 
 int
 main(int argc, char *argv[])



CVS commit: src/bin/cat

2023-12-07 Thread Roland Illig
Module Name:src
Committed By:   rillig
Date:   Thu Dec  7 20:02:07 UTC 2023

Modified Files:
src/bin/cat: cat.c

Log Message:
cat: reduce visibility of local functions

No functional change.


To generate a diff of this commit:
cvs rdiff -u -r1.58 -r1.59 src/bin/cat/cat.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/external/bsd/elftoolchain/dist/common/sys

2023-12-07 Thread Joseph Koshy
Module Name:src
Committed By:   jkoshy
Date:   Thu Dec  7 17:28:36 UTC 2023

Modified Files:
src/external/bsd/elftoolchain/dist/common/sys: elfconstants.m4

Log Message:
Update elfconstants.m4 to upstream [r3986].

- Add the NetBSD spelling of a 386 relocation.
- Add VAX relocations.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 \
src/external/bsd/elftoolchain/dist/common/sys/elfconstants.m4

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/external/bsd/elftoolchain/dist/common/sys

2023-12-07 Thread Joseph Koshy
Module Name:src
Committed By:   jkoshy
Date:   Thu Dec  7 17:28:36 UTC 2023

Modified Files:
src/external/bsd/elftoolchain/dist/common/sys: elfconstants.m4

Log Message:
Update elfconstants.m4 to upstream [r3986].

- Add the NetBSD spelling of a 386 relocation.
- Add VAX relocations.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 \
src/external/bsd/elftoolchain/dist/common/sys/elfconstants.m4

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/elftoolchain/dist/common/sys/elfconstants.m4
diff -u src/external/bsd/elftoolchain/dist/common/sys/elfconstants.m4:1.4 src/external/bsd/elftoolchain/dist/common/sys/elfconstants.m4:1.5
--- src/external/bsd/elftoolchain/dist/common/sys/elfconstants.m4:1.4	Mon May  2 20:27:43 2022
+++ src/external/bsd/elftoolchain/dist/common/sys/elfconstants.m4	Thu Dec  7 17:28:36 2023
@@ -1,4 +1,4 @@
-dnl 	$NetBSD: elfconstants.m4,v 1.4 2022/05/02 20:27:43 jkoshy Exp $
+dnl 	$NetBSD: elfconstants.m4,v 1.5 2023/12/07 17:28:36 jkoshy Exp $
 # Copyright (c) 2010,2021 Joseph Koshy
 # All rights reserved.
 
@@ -33,7 +33,7 @@ dnl 	$NetBSD: elfconstants.m4,v 1.4 2022
 # - The "Linkers and Libraries Guide", from Sun Microsystems.
 
 define(`VCSID_ELFCONSTANTS_M4',
-	`Id: elfconstants.m4 3980 2022-05-02 19:50:00Z jkoshy')
+	`$Id: elfconstants.m4,v 1.5 2023/12/07 17:28:36 jkoshy Exp $')
 
 # In the following definitions, `_' is an M4 macro that is meant to be
 # expanded later.  Its intended usage is:
@@ -1605,6 +1605,7 @@ _(R_386_GOT32,		3)
 _(R_386_PLT32,		4)
 _(R_386_COPY,		5)
 _(R_386_GLOB_DAT,	6)
+_(R_386_JMP_SLOT,	7)
 _(R_386_JUMP_SLOT,	7)
 _(R_386_RELATIVE,	8)
 _(R_386_GOTOFF,		9)
@@ -2402,6 +2403,22 @@ _(R_SPARC_GOTDATA_OP,	84)
 _(R_SPARC_H34,		85)
 ')
 
+define(`DEFINE_VAX_RELOCATIONS',`
+_(R_VAX_NONE,   0)
+_(R_VAX_32, 1)
+_(R_VAX_16, 2)
+_(R_VAX_8,  3)
+_(R_VAX_PC32,   4)
+_(R_VAX_PC16,   5)
+_(R_VAX_PC8,6)
+_(R_VAX_GOT32,  7)
+_(R_VAX_PLT32, 13)
+_(R_VAX_COPY,  19)
+_(R_VAX_GLOB_DAT,  20)
+_(R_VAX_JMP_SLOT,  21)
+_(R_VAX_RELATIVE,  22)
+')
+
 define(`DEFINE_X86_64_RELOCATIONS',`
 _(R_X86_64_NONE,	0)
 _(R_X86_64_64,		1)
@@ -2457,6 +2474,7 @@ DEFINE_PPC32_RELOCATIONS()
 DEFINE_PPC64_RELOCATIONS()
 DEFINE_RISCV_RELOCATIONS()
 DEFINE_SPARC_RELOCATIONS()
+DEFINE_VAX_RELOCATIONS()
 DEFINE_X86_64_RELOCATIONS()
 ')
 



CVS commit: src/share/man/man7

2023-12-07 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu Dec  7 17:24:22 UTC 2023

Modified Files:
src/share/man/man7: stack.7

Log Message:
stack(7): Fix diagram of non-main thread stacks.

Had stackaddr (pthread_attr_setstack parameter, lowest-numbered
virtual address of stack region) confused with stack base (where the
stack grows from, which is the highest-numbered virtual address on
machines where stack grows down).

PR pkg/57708

XXX pullup-10


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/share/man/man7/stack.7

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man7/stack.7
diff -u src/share/man/man7/stack.7:1.5 src/share/man/man7/stack.7:1.6
--- src/share/man/man7/stack.7:1.5	Thu Dec  7 17:15:48 2023
+++ src/share/man/man7/stack.7	Thu Dec  7 17:24:22 2023
@@ -1,4 +1,4 @@
-.\"	$NetBSD: stack.7,v 1.5 2023/12/07 17:15:48 riastradh Exp $
+.\"	$NetBSD: stack.7,v 1.6 2023/12/07 17:24:22 riastradh Exp $
 .\"
 .\" Copyright (c) 2023 The NetBSD Foundation, Inc.
 .\" All rights reserved.
@@ -191,14 +191,14 @@ thread's stack region by default, and th
 after creation.
 On architectures where the stack grows down, the layout is:
 .Bd -literal
-++ stackaddr
+++ stack base = stackaddr + stacksize + guardsize
 | stack  |
 | .  |
 | .  | <-- stack pointer (varies during execution)
 | .  |
-++ stackaddr - stacksize
+++ stackaddr
 | guard/redzone  |
-++ stackaddr - stacksize - guardsize
+++ stackaddr - guardsize
 .Ed
 .Pp
 On architectures where the stack grows up, the layout is:
@@ -210,7 +210,7 @@ On architectures where the stack grows u
 | .  | <-- stack pointer (varies during execution)
 | .  |
 | stack  |
-++ stackaddr
+++ stack base = stackaddr
 .Ed
 .Pp
 The parameters stackaddr, stacksize, and guardsize can be obtained from



CVS commit: src/share/man/man7

2023-12-07 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu Dec  7 17:24:22 UTC 2023

Modified Files:
src/share/man/man7: stack.7

Log Message:
stack(7): Fix diagram of non-main thread stacks.

Had stackaddr (pthread_attr_setstack parameter, lowest-numbered
virtual address of stack region) confused with stack base (where the
stack grows from, which is the highest-numbered virtual address on
machines where stack grows down).

PR pkg/57708

XXX pullup-10


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/share/man/man7/stack.7

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/share/man/man7

2023-12-07 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu Dec  7 17:15:48 UTC 2023

Modified Files:
src/share/man/man7: stack.7

Log Message:
stack(7): Minor clarifications and wording tweaks.

Suggested by pgoyette@ and uwe@.

PR pkg/57708

XXX pullup-10


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/share/man/man7/stack.7

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man7/stack.7
diff -u src/share/man/man7/stack.7:1.4 src/share/man/man7/stack.7:1.5
--- src/share/man/man7/stack.7:1.4	Thu Nov 23 21:44:55 2023
+++ src/share/man/man7/stack.7	Thu Dec  7 17:15:48 2023
@@ -1,4 +1,4 @@
-.\"	$NetBSD: stack.7,v 1.4 2023/11/23 21:44:55 riastradh Exp $
+.\"	$NetBSD: stack.7,v 1.5 2023/12/07 17:15:48 riastradh Exp $
 .\"
 .\" Copyright (c) 2023 The NetBSD Foundation, Inc.
 .\" All rights reserved.
@@ -133,8 +133,7 @@ although the term
 is also sometimes used to mean a fixed space
 .Em above
 the stack pointer (in the direction of stack growth) that the system
-guarantees will it will not overwrite when calling a signal handler in
-the
+guarantees it will not overwrite when calling a signal handler in the
 .Tn ABI
 of some architectures; see also
 .Xr sigaltstack 2
@@ -187,8 +186,9 @@ are defined in
 .Ss Non-main threads
 Threads created with
 .Xr pthread_create 3
-have stacks allocated at dynamically chosen addresses, and the stacks
-cannot be resized after creation.
+have stacks allocated at dynamically chosen addresses outside the main
+thread's stack region by default, and their stacks cannot be resized
+after creation.
 On architectures where the stack grows down, the layout is:
 .Bd -literal
 ++ stackaddr
@@ -243,11 +243,13 @@ guardsize is the value of the
 .Li vm.guard_size
 .Xr sysctl 7
 knob at the time of program startup.
-(Note that this means the
+.Po
+Note that this means the
 .Xr pthread 3
 view of the main thread's stack guard may not coincide with the actual
 stack guard \(em it may overlap with, or lie entirely in, the
-inaccessible pages of the stack reserved on program start.)
+inaccessible pages of the stack reserved on program start.
+.Pc
 However, if the program changes its soft stack rlimit with
 .Xr setrlimit 2 ,
 this snapshot may become stale.



CVS commit: src/share/man/man7

2023-12-07 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu Dec  7 17:15:48 UTC 2023

Modified Files:
src/share/man/man7: stack.7

Log Message:
stack(7): Minor clarifications and wording tweaks.

Suggested by pgoyette@ and uwe@.

PR pkg/57708

XXX pullup-10


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/share/man/man7/stack.7

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/atari

2023-12-07 Thread Jason R Thorpe
Module Name:src
Committed By:   thorpej
Date:   Thu Dec  7 16:56:09 UTC 2023

Modified Files:
src/sys/arch/atari/atari: atari_init.c bus.c machdep.c
src/sys/arch/atari/include: bus_funcs.h

Log Message:
extent(9) -> vmem(9)


To generate a diff of this commit:
cvs rdiff -u -r1.107 -r1.108 src/sys/arch/atari/atari/atari_init.c
cvs rdiff -u -r1.68 -r1.69 src/sys/arch/atari/atari/bus.c
cvs rdiff -u -r1.188 -r1.189 src/sys/arch/atari/atari/machdep.c
cvs rdiff -u -r1.2 -r1.3 src/sys/arch/atari/include/bus_funcs.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libpthread/pthread_attr_getguardsize.3
diff -u src/lib/libpthread/pthread_attr_getguardsize.3:1.5 src/lib/libpthread/pthread_attr_getguardsize.3:1.6
--- src/lib/libpthread/pthread_attr_getguardsize.3:1.5	Sun Oct 22 16:37:24 2017
+++ src/lib/libpthread/pthread_attr_getguardsize.3	Thu Dec  7 16:55:01 2023
@@ -1,4 +1,4 @@
-.\"	$NetBSD: pthread_attr_getguardsize.3,v 1.5 2017/10/22 16:37:24 abhinav Exp $
+.\"	$NetBSD: pthread_attr_getguardsize.3,v 1.6 2023/12/07 16:55:01 riastradh Exp $
 .\"
 .\" Copyright (c) 2010 Jukka Ruohonen 
 .\" All rights reserved.
@@ -123,3 +123,27 @@ There was insufficient memory.
 .Sh STANDARDS
 Both functions conform to
 .St -p1003.1-2008 .
+.Sh BUGS
+Older versions of
+.Nx ,
+prior to 10.0, 9.4, and 8.3, incorrectly adjust the stack address by
+the guard size in threads configured with
+.Xr pthread_attr_setstack 3 ,
+instead of ignoring the guard size in that case as
+.Tn POSIX
+prescribes
+.Po
+see
+.Lk https://gnats.NetBSD.org/57721 "PR lib/57721"
+.Pc .
+.Pp
+Even if you didn't set a nonzero guard size with
+.Fn pthread_attr_setguardsize ,
+the system will choose a nonzero default guard size.
+.Pp
+To work around this in applications that run on older and newer
+versions of
+.Nx ,
+as well as on other operating systems, you can safely set the guard
+size to zero:
+.Dl "pthread_attr_setguardsize(, 0);"

Index: src/lib/libpthread/pthread_attr_getstack.3
diff -u src/lib/libpthread/pthread_attr_getstack.3:1.8 src/lib/libpthread/pthread_attr_getstack.3:1.9
--- src/lib/libpthread/pthread_attr_getstack.3:1.8	Mon Oct 23 01:03:23 2017
+++ src/lib/libpthread/pthread_attr_getstack.3	Thu Dec  7 16:55:01 2023
@@ -1,4 +1,4 @@
-.\"	$NetBSD: pthread_attr_getstack.3,v 1.8 2017/10/23 01:03:23 wiz Exp $
+.\"	$NetBSD: pthread_attr_getstack.3,v 1.9 2023/12/07 16:55:01 riastradh Exp $
 .\"
 .\" Copyright (c) 2010 Jukka Ruohonen 
 .\" All rights reserved.
@@ -177,3 +177,27 @@ and
 were however removed from the specification in the
 .St -p1003.1-2008
 revision.
+.Sh BUGS
+Older versions of
+.Nx ,
+prior to 10.0, 9.4, and 8.3, incorrectly adjust the stack address by
+the guard size in threads configured with
+.Fn pthread_attr_setstack ,
+instead of ignoring the guard size in that case as
+.Tn POSIX
+prescribes
+.Po
+see
+.Lk https://gnats.NetBSD.org/57721 "PR lib/57721"
+.Pc .
+.Pp
+Even if you didn't set a nonzero guard size with
+.Xr pthread_attr_setguardsize 3 ,
+the system will choose a nonzero default guard size.
+.Pp
+To work around this in applications that run on older and newer
+versions of
+.Nx ,
+as well as on other operating systems, you can safely set the guard
+size to zero:
+.Dl "pthread_attr_setguardsize(, 0);"



CVS commit: src/tests/lib/libc/sys

2023-12-07 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu Dec  7 16:54:44 UTC 2023

Modified Files:
src/tests/lib/libc/sys: Makefile t_setrlimit.c

Log Message:
t_setrlimit: Narrow the scope of stack-protector warning suppression.


To generate a diff of this commit:
cvs rdiff -u -r1.75 -r1.76 src/tests/lib/libc/sys/Makefile
cvs rdiff -u -r1.10 -r1.11 src/tests/lib/libc/sys/t_setrlimit.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tests/lib/libc/sys/Makefile
diff -u src/tests/lib/libc/sys/Makefile:1.75 src/tests/lib/libc/sys/Makefile:1.76
--- src/tests/lib/libc/sys/Makefile:1.75	Fri Nov 24 17:19:55 2023
+++ src/tests/lib/libc/sys/Makefile	Thu Dec  7 16:54:44 2023
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.75 2023/11/24 17:19:55 christos Exp $
+# $NetBSD: Makefile,v 1.76 2023/12/07 16:54:44 riastradh Exp $
 
 MKMAN=	no
 
@@ -158,6 +158,5 @@ CWARNFLAGS.gcc+=	${CC_WNO_ADDRESS_OF_PAC
 
 # Explicitly breaks this
 COPTS.t_wait.c+=	${CC_WNO_ARRAY_BOUNDS} ${CC_WNO_STRINGOP_OVERFLOW}
-COPTS.t_setrlimit.c+=	-Wno-error=stack-protector
 
 .include 

Index: src/tests/lib/libc/sys/t_setrlimit.c
diff -u src/tests/lib/libc/sys/t_setrlimit.c:1.10 src/tests/lib/libc/sys/t_setrlimit.c:1.11
--- src/tests/lib/libc/sys/t_setrlimit.c:1.10	Wed Nov 22 02:20:34 2023
+++ src/tests/lib/libc/sys/t_setrlimit.c	Thu Dec  7 16:54:44 2023
@@ -1,4 +1,4 @@
-/* $NetBSD: t_setrlimit.c,v 1.10 2023/11/22 02:20:34 riastradh Exp $ */
+/* $NetBSD: t_setrlimit.c,v 1.11 2023/12/07 16:54:44 riastradh Exp $ */
 
 /*-
  * Copyright (c) 2011 The NetBSD Foundation, Inc.
@@ -29,7 +29,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include 
-__RCSID("$NetBSD: t_setrlimit.c,v 1.10 2023/11/22 02:20:34 riastradh Exp $");
+__RCSID("$NetBSD: t_setrlimit.c,v 1.11 2023/12/07 16:54:44 riastradh Exp $");
 
 #include 
 #include 
@@ -534,6 +534,26 @@ ATF_TC_HEAD(setrlimit_stack_growshrink, 
 }
 
 /*
+ * checkstackchild(n)
+ *
+ *	Allocate an array of size n on the stack, and verify it can be
+ *	used.  If it can't be used, this will crash with SIGSEGV,
+ *	deliberately.
+ */
+_Pragma("GCC diagnostic push")
+_Pragma("GCC diagnostic ignored \"-Wstack-protector\"")
+static void
+checkstackchild(size_t n)
+{
+	volatile char *const x = alloca(n);
+	size_t i;
+
+	for (i = 0; i < n; i++)
+		x[i] = 0x1a;
+}
+_Pragma("GCC diagnostic pop")
+
+/*
  * checkstack(n, expectsegv)
  *
  *	Check whether we can allocate an array of size n on the stack.
@@ -555,14 +575,11 @@ static void
 checkstack(size_t n, int expectsegv)
 {
 	pid_t forked, waited;
-	size_t i;
 	int status;
 
 	RL(forked = fork());
 	if (forked == 0) {	/* child */
-		volatile char *const x = alloca(n);
-		for (i = 0; i < n; i++)
-			x[i] = 0x1a;
+		checkstackchild(n);
 		_exit(expectsegv);
 	}
 



CVS commit: src/tests/lib/libc/sys

2023-12-07 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu Dec  7 16:54:44 UTC 2023

Modified Files:
src/tests/lib/libc/sys: Makefile t_setrlimit.c

Log Message:
t_setrlimit: Narrow the scope of stack-protector warning suppression.


To generate a diff of this commit:
cvs rdiff -u -r1.75 -r1.76 src/tests/lib/libc/sys/Makefile
cvs rdiff -u -r1.10 -r1.11 src/tests/lib/libc/sys/t_setrlimit.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/netinet6

2023-12-07 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Thu Dec  7 16:47:44 UTC 2023

Modified Files:
src/sys/netinet6: in6.c

Log Message:
Identify the need to rework the COMPAT_* code to be more
module-aware.

This is an XXX comment block only, NFCI.


To generate a diff of this commit:
cvs rdiff -u -r1.289 -r1.290 src/sys/netinet6/in6.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/netinet6/in6.c
diff -u src/sys/netinet6/in6.c:1.289 src/sys/netinet6/in6.c:1.290
--- src/sys/netinet6/in6.c:1.289	Thu Aug  3 05:44:22 2023
+++ src/sys/netinet6/in6.c	Thu Dec  7 16:47:44 2023
@@ -1,4 +1,4 @@
-/*	$NetBSD: in6.c,v 1.289 2023/08/03 05:44:22 ozaki-r Exp $	*/
+/*	$NetBSD: in6.c,v 1.290 2023/12/07 16:47:44 pgoyette Exp $	*/
 /*	$KAME: in6.c,v 1.198 2001/07/18 09:12:38 itojun Exp $	*/
 
 /*
@@ -62,7 +62,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: in6.c,v 1.289 2023/08/03 05:44:22 ozaki-r Exp $");
+__KERNEL_RCSID(0, "$NetBSD: in6.c,v 1.290 2023/12/07 16:47:44 pgoyette Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_inet.h"
@@ -105,6 +105,17 @@ __KERNEL_RCSID(0, "$NetBSD: in6.c,v 1.28
 #include 
 #include 
 
+/* XXX
+ *
+ * The COMPAT_* code here, along with call-sites in nd6.c and
+ * icmp6.c, needs to be reworked to use compat hooks.  As it
+ * stands right now, the compat code only gets built if it is
+ * iincluded in the kernel at build time;  building and loading
+ * compat_* modules will not include this compat code!
+ *
+ * XXX
+ */
+
 #ifdef COMPAT_50
 #include 
 #endif



CVS commit: src/sys/netinet6

2023-12-07 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Thu Dec  7 16:47:44 UTC 2023

Modified Files:
src/sys/netinet6: in6.c

Log Message:
Identify the need to rework the COMPAT_* code to be more
module-aware.

This is an XXX comment block only, NFCI.


To generate a diff of this commit:
cvs rdiff -u -r1.289 -r1.290 src/sys/netinet6/in6.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/lib/libc/time

2023-12-07 Thread Valery Ushakov
Module Name:src
Committed By:   uwe
Date:   Thu Dec  7 16:16:03 UTC 2023

Modified Files:
src/lib/libc/time: zic.8

Log Message:
zic(8): more markup fixes

Still need to go over the tables.


To generate a diff of this commit:
cvs rdiff -u -r1.45 -r1.46 src/lib/libc/time/zic.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/lib/libc/time

2023-12-07 Thread Valery Ushakov
Module Name:src
Committed By:   uwe
Date:   Thu Dec  7 16:16:03 UTC 2023

Modified Files:
src/lib/libc/time: zic.8

Log Message:
zic(8): more markup fixes

Still need to go over the tables.


To generate a diff of this commit:
cvs rdiff -u -r1.45 -r1.46 src/lib/libc/time/zic.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/time/zic.8
diff -u src/lib/libc/time/zic.8:1.45 src/lib/libc/time/zic.8:1.46
--- src/lib/libc/time/zic.8:1.45	Wed Dec  6 21:42:01 2023
+++ src/lib/libc/time/zic.8	Thu Dec  7 16:16:03 2023
@@ -1,4 +1,4 @@
-.\" $NetBSD: zic.8,v 1.45 2023/12/06 21:42:01 kre Exp $
+.\" $NetBSD: zic.8,v 1.46 2023/12/07 16:16:03 uwe Exp $
 .\" @(#)zic.8	8.6
 .\" This file is in the public domain, so clarified as of
 .\" 2009-05-17 by Arthur David Olson.
@@ -22,7 +22,7 @@
 .Op Fl t Ar file
 .Op Fl v
 .Op Fl y Ar command
-.Op Ar Filename ...
+.Op Ar
 .Sh DESCRIPTION
 The
 .Nm
@@ -30,16 +30,15 @@ program reads text from the file(s) name
 and creates the timezone information format (TZif) files
 specified in this input.
 If a
-.Ar filename
+.Ar file
 is
-.Ar \&- ,
+.Ql \&- ,
 standard input is read.
-.Pp
-.Sh OPTIONS
-.Bl -tag -width XX -compact
-.It Fl \-version
+.Ss Options
+.Bl -tag -width Fl
+.It Fl Fl version
 Output version information and exit.
-.It Fl \-help
+.It Fl Fl help
 Output short usage message and exit.
 .It Fl b Ar bloat
 Output backward-compatibility data as specified by
@@ -47,37 +46,40 @@ Output backward-compatibility data as sp
 If
 .Ar bloat
 is
-.Dv fat ,
+.Ql fat ,
 generate additional data entries that work around potential bugs or
 incompatibilities in older software, such as software that mishandles
 the 64-bit generated data.
 If
 .Ar bloat
 is
-.Dv slim ,
+.Ql slim ,
 keep the output files small; this can help check for the bugs
 and incompatibilities.
 The default is
-.Dv slim ,
+.Ql slim ,
 as software that mishandles 64-bit data typically
 mishandles timestamps after the year 2038 anyway.
 Also see the
 .Fl r
 option for another way to alter output size.
 .It Fl d Ar directory
-Create time conversion information files in the named directory rather than
-in the standard directory named below.
+Create time conversion information files in the named
+.Ar directory
+rather than in the standard directory named below.
 .It Fl l Ar timezone
-Use the 
+Use the
 .Ar timezone
 as local time.
 .Nm
 will act as if the input contained a link line of the form
-.Dl Link	timezone	localtime
+.Pp
+.D1 Li Link Ar timezone Li localtime
+.Pp
 If
 .Ar timezone
 is
-.Dv \&- ,
+.Ql - ,
 any already-existing link is removed.
 .It Fl L Ar leapsecondfilename
 Read leap second information from the file with the given name.
@@ -85,32 +87,32 @@ If this option is not used,
 no leap second information appears in output files.
 .It Fl p Ar timezone
 Use
-.Ar timezone's
-rules when handling POSIX-format
-TZ strings like 
-.Qq EET\&-2EEST
+.Ar timezone Ap s
+rules when handling POSIX-format TZ strings like
+.Ql EET-2EEST
 that lack transition rules.
 .Nm
 will act as if the input contained a link line of the form
-.Dl Link	timezone	posixrules
+.Pp
+.D1 Li Link Ar timezone Li posixrules
 .Pp
 Unless
 .Ar timezone
 is
-.Dq \&- ,
+.Ql - ,
 this option is obsolete and poorly supported.
 Among other things it should not be used for timestamps after the year 2037,
 and it should not be combined with
-.Fl b Ar slim
+.Fl b Cm slim
 if
-.Va timezone's
+.Ar timezone Ap s
 transitions are at standard time or Universal Time (UT) instead of local time.
 If
 .Ar timezone
 is
-.Dv \&- ,
+.Ql - ,
 any already-existing link is removed.
-.It Fl r Op Ar @lo / Op Ar @hi
+.It Fl r Op Cm @ Ns Ar lo Ns Op Cm /@ Ns Ar hi
 Limit the applicability of output files
 to timestamps in the range from
 .Ar lo
@@ -127,36 +129,36 @@ The output files use UT offset 0 and abb
 .Qq "\*-00"
 in place of the omitted timestamp data.
 For example,
-.Bd -literal
-zic -r @0
-.Ed
+.Pp
+.Dl zic -r @0
+.Pp
 omits data intended for negative timestamps (i.e., before the Epoch), and
-.Bd -literal
-zic -r @0/@2147483648
-.Ed
+.Pp
+.Dl zic -r @0/@2147483648
+.Pp
 outputs data intended only for nonnegative timestamps that fit into
 31-bit signed integers.
-Or using 
+Or using
 .Xr date 1 ,
-.Bd -literal
-zic -r @$(date +%s)
-.Ed
+.Pp
+.Dl zic -r @$(date +%s)
+.Pp
 omits data intended for past timestamps.
 Although this option typically reduces the output file's size,
 the size can increase due to the need to represent the timestamp range
 boundaries, particularly if
 .Ar hi
 causes a TZif file to contain explicit entries for
-.Ar pre- hi
+.No pre- Ns Ar hi
 transitions rather than concisely representing them
 with an extended POSIX TZ string.
 Also see the
-.Fl b Ar slim
+.Fl b Cm slim
 option for another way to shrink output size.
-.It Fl R Ar @hi
+.It Fl R Cm @ Ns Ar hi
 Generate redundant trailing explicit transitions for timestamps
 

CVS commit: src/share/misc

2023-12-07 Thread Jan Schaumann
Module Name:src
Committed By:   jschauma
Date:   Thu Dec  7 16:03:32 UTC 2023

Modified Files:
src/share/misc: acronyms.comp

Log Message:
+STEKsession ticket encryption key


To generate a diff of this commit:
cvs rdiff -u -r1.382 -r1.383 src/share/misc/acronyms.comp

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/misc/acronyms.comp
diff -u src/share/misc/acronyms.comp:1.382 src/share/misc/acronyms.comp:1.383
--- src/share/misc/acronyms.comp:1.382	Tue Dec  5 19:28:40 2023
+++ src/share/misc/acronyms.comp	Thu Dec  7 16:03:32 2023
@@ -1,4 +1,4 @@
-$NetBSD: acronyms.comp,v 1.382 2023/12/05 19:28:40 jschauma Exp $
+$NetBSD: acronyms.comp,v 1.383 2023/12/07 16:03:32 jschauma Exp $
 3WHS	three-way handshake
 8VSB	8-state vestigial side band modulation
 AA	anti-aliasing
@@ -1656,6 +1656,7 @@ SSRF	server-side request forgery
 SSTP 	secure socket tunneling protocol
 STC	software thermal control
 STD	state transition diagram
+STEK	session ticket encryption key
 STM	software transactional memory
 STOMP	Streaming Text Oriented Messaging Protocol
 STP	Spanning Tree Protocol



CVS commit: src/share/misc

2023-12-07 Thread Jan Schaumann
Module Name:src
Committed By:   jschauma
Date:   Thu Dec  7 16:03:32 UTC 2023

Modified Files:
src/share/misc: acronyms.comp

Log Message:
+STEKsession ticket encryption key


To generate a diff of this commit:
cvs rdiff -u -r1.382 -r1.383 src/share/misc/acronyms.comp

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/kern

2023-12-07 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Thu Dec  7 09:00:32 UTC 2023

Modified Files:
src/sys/kern: tty.c

Log Message:
There's no COMPAT_60 code left here, so no need for conditional
inclusion of header file.


To generate a diff of this commit:
cvs rdiff -u -r1.311 -r1.312 src/sys/kern/tty.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/kern/tty.c
diff -u src/sys/kern/tty.c:1.311 src/sys/kern/tty.c:1.312
--- src/sys/kern/tty.c:1.311	Mon May 22 14:07:37 2023
+++ src/sys/kern/tty.c	Thu Dec  7 09:00:32 2023
@@ -1,4 +1,4 @@
-/*	$NetBSD: tty.c,v 1.311 2023/05/22 14:07:37 riastradh Exp $	*/
+/*	$NetBSD: tty.c,v 1.312 2023/12/07 09:00:32 pgoyette Exp $	*/
 
 /*-
  * Copyright (c) 2008, 2020 The NetBSD Foundation, Inc.
@@ -63,7 +63,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: tty.c,v 1.311 2023/05/22 14:07:37 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: tty.c,v 1.312 2023/12/07 09:00:32 pgoyette Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_compat_netbsd.h"
@@ -103,10 +103,6 @@ __KERNEL_RCSID(0, "$NetBSD: tty.c,v 1.31
 #include 
 #include 
 
-#ifdef COMPAT_60
-#include 
-#endif /* COMPAT_60 */
-
 static int	ttnread(struct tty *);
 static void	ttyblock(struct tty *);
 static void	ttyecho(int, struct tty *);



CVS commit: src/sys/kern

2023-12-07 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Thu Dec  7 09:00:32 UTC 2023

Modified Files:
src/sys/kern: tty.c

Log Message:
There's no COMPAT_60 code left here, so no need for conditional
inclusion of header file.


To generate a diff of this commit:
cvs rdiff -u -r1.311 -r1.312 src/sys/kern/tty.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.
Index: src/sys/arch/atari/atari/atari_init.c
diff -u src/sys/arch/atari/atari/atari_init.c:1.107 src/sys/arch/atari/atari/atari_init.c:1.108
--- src/sys/arch/atari/atari/atari_init.c:1.107	Fri Jan  6 10:28:27 2023
+++ src/sys/arch/atari/atari/atari_init.c	Thu Dec  7 16:56:09 2023
@@ -1,4 +1,4 @@
-/*	$NetBSD: atari_init.c,v 1.107 2023/01/06 10:28:27 tsutsui Exp $	*/
+/*	$NetBSD: atari_init.c,v 1.108 2023/12/07 16:56:09 thorpej Exp $	*/
 
 /*
  * Copyright (c) 1995 Leo Weppelman
@@ -33,7 +33,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: atari_init.c,v 1.107 2023/01/06 10:28:27 tsutsui Exp $");
+__KERNEL_RCSID(0, "$NetBSD: atari_init.c,v 1.108 2023/12/07 16:56:09 thorpej Exp $");
 
 #include "opt_ddb.h"
 #include "opt_mbtype.h"
@@ -671,10 +671,10 @@ start_c(int id, u_int ttphystart, u_int 
 	init_stmem();
 
 	/*
 	 * Initialize the iomem extent for bus_space(9) to manage address
 	 * spaces and allocate the physical RAM from the extent map.
 	 */
-	atari_bus_space_extent_init(0x0, 0x);
+	atari_bus_space_arena_init(0x0, 0x);
 	for (i = 0; i < NMEM_SEGS && boot_segs[i].end != 0; i++) {
 		if (atari_bus_space_alloc_physmem(boot_segs[i].start,
 		boot_segs[i].end)) {
@@ -671,10 +671,10 @@ start_c(int id, u_int ttphystart, u_int 
 
 	/*
-	 * Initialize the iomem extent for bus_space(9) to manage address
+	 * Initialize the iomem arena for bus_space(9) to manage address
 	 * spaces and allocate the physical RAM from the extent map.
 	 */

Index: src/sys/arch/atari/atari/bus.c
diff -u src/sys/arch/atari/atari/bus.c:1.68 src/sys/arch/atari/atari/bus.c:1.69
--- src/sys/arch/atari/atari/bus.c:1.68	Fri Jan  6 10:28:27 2023
+++ src/sys/arch/atari/atari/bus.c	Thu Dec  7 16:56:09 2023
@@ -1,4 +1,4 @@
-/*	$NetBSD: bus.c,v 1.68 2023/01/06 10:28:27 tsutsui Exp $	*/
+/*	$NetBSD: bus.c,v 1.69 2023/12/07 16:56:09 thorpej Exp $	*/
 
 /*-
  * Copyright (c) 1998 The NetBSD Foundation, Inc.
@@ -33,7 +33,7 @@
 #include "opt_m68k_arch.h"
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: bus.c,v 1.68 2023/01/06 10:28:27 tsutsui Exp $");
+__KERNEL_RCSID(0, "$NetBSD: bus.c,v 1.69 2023/12/07 16:56:09 thorpej Exp $");
 
 #include 
 #include 
@@ -41,6 +41,7 @@ __KERNEL_RCSID(0, "$NetBSD: bus.c,v 1.68
 #include 
 #include 
 #include 
+#include 
 
 #include 
 
@@ -50,16 +51,16 @@ __KERNEL_RCSID(0, "$NetBSD: bus.c,v 1.68
 #include 
 
 /*
  * Extent maps to manage all memory space, including I/O ranges.  Allocate
  * storage for 16 regions in each, initially.  Later, iomem_malloc_safe
  * will indicate that it's safe to use malloc() to dynamically allocate
  * region descriptors.
  * This means that the fixed static storage is only used for registrating
  * the found memory regions and the bus-mapping of the console.
  */
-static long iomem_ex_storage[EXTENT_FIXED_STORAGE_SIZE(16) / sizeof(long)];
-static struct extent *iomem_ex;
-static int iomem_malloc_safe = 0;
+#define	IOMEM_BTAG_COUNT	VMEM_EST_BTCOUNT(1, 16)
+static struct vmem iomem_arena_store;
+static struct vmem_btag iomem_btag_store[IOMEM_BTAG_COUNT];
+static vmem_t *iomem_arena;
 
 static int  _bus_dmamap_load_buffer(bus_dma_tag_t tag, bus_dmamap_t,
 		void *, bus_size_t, struct vmspace *, int, paddr_t *,
@@ -80,9 +81,12 @@ extern paddr_t avail_end;
  * very early stage of the system configuration.
  */
 static pt_entry_t	*bootm_ptep;
-static long		bootm_ex_storage[EXTENT_FIXED_STORAGE_SIZE(32) /
-sizeof(long)];
-static struct extent	*bootm_ex;
+static vaddr_t		 bootm_start;
+static vaddr_t		 bootm_end;		/* inclusive */
+#define	BOOTM_BTAG_COUNT	VMEM_EST_BTCOUNT(1, 32)
+static struct vmem	 bootm_arena_store;
+static struct vmem_btag	 bootm_btag_store[BOOTM_BTAG_COUNT];
+static vmem_t *		 bootm_arena;
 
 static vaddr_t	bootm_alloc(paddr_t pa, u_long size, int flags);
 static int	bootm_free(vaddr_t va, u_long size);
@@ -91,10 +95,24 @@ void
 bootm_init(vaddr_t va, void *ptep, vsize_t size)
 {
 
-	bootm_ex = extent_create("bootmem", va, va + size,
-	(void *)bootm_ex_storage, sizeof(bootm_ex_storage),
-	EX_NOCOALESCE|EX_NOWAIT);
+	bootm_start = va;
+	bootm_end = va + size - 1;
 	bootm_ptep = (pt_entry_t *)ptep;
+
+	bootm_arena = vmem_init(_arena_store,
+"bootmem",		/* name */
+0,			/* addr */
+0,			/* size */
+PAGE_SIZE,		/* quantum */
+NULL,			/* importfn */
+NULL,			/* releasefn */
+NULL,			/* source */
+0,			/* qcache_max */
+
@@ -50,16 +51,16 @@ __KERNEL_RCSID(0, "$NetBSD: bus.c,v 1.68
 
 /*
- * Extent maps to manage all memory space, including I/O ranges.  Allocate
- * storage for 16 regions in each, initially.  Later, iomem_malloc_safe
- * will indicate that it's safe to use malloc() to dynamically allocate
- * region descriptors.
+ * Vmem arena to manage all memory space, including I/O ranges.  Allocate
+ * storage for 16 regions in each, initially.
+ *
  * This means that the fixed static storage is only used for registrating
  * the found memory regions and the bus-mapping of the console.

CVS commit: src/sys/arch/atari

2023-12-07 Thread Jason R Thorpe
Module Name:src
Committed By:   thorpej
Date:   Thu Dec  7 16:56:09 UTC 2023

Modified Files:
src/sys/arch/atari/atari: atari_init.c bus.c machdep.c
src/sys/arch/atari/include: bus_funcs.h

Log Message:
extent(9) -> vmem(9)


To generate a diff of this commit:
cvs rdiff -u -r1.107 -r1.108 src/sys/arch/atari/atari/atari_init.c
cvs rdiff -u -r1.68 -r1.69 src/sys/arch/atari/atari/bus.c
cvs rdiff -u -r1.188 -r1.189 src/sys/arch/atari/atari/machdep.c
cvs rdiff -u -r1.2 -r1.3 src/sys/arch/atari/include/bus_funcs.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/lib/libpthread

2023-12-07 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu Dec  7 16:55:01 UTC 2023

Modified Files:
src/lib/libpthread: pthread_attr_getguardsize.3 pthread_attr_getstack.3

Log Message:
pthread: Document the setstack vs setguardsize bug.

Suggest the safe, compatible workaround.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/lib/libpthread/pthread_attr_getguardsize.3
cvs rdiff -u -r1.8 -r1.9 src/lib/libpthread/pthread_attr_getstack.3

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/lib/libpthread

2023-12-07 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu Dec  7 16:55:01 UTC 2023

Modified Files:
src/lib/libpthread: pthread_attr_getguardsize.3 pthread_attr_getstack.3

Log Message:
pthread: Document the setstack vs setguardsize bug.

Suggest the safe, compatible workaround.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/lib/libpthread/pthread_attr_getguardsize.3
cvs rdiff -u -r1.8 -r1.9 src/lib/libpthread/pthread_attr_getstack.3

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
